@@ -234,9 +234,14 @@ class MainWindow(QtWidgets.QMainWindow):
         self.flag_widget.itemChanged.connect(self.setDirty)
 
 
+
+
+        #self.labelList.itemActivated.connect(self.labelSelectionChanged)
         self.labelList.itemSelectionChanged.connect(self.labelSelectionChanged)
         self.labelList.itemDoubleClicked.connect(self.editLabel)
         # Connect to itemChanged to detect checkbox changes.
+        self.labelList.itemChanged.connect(self.labelItemChanged)
+        self.labelList.itemDropped.connect(self.labelOrderChanged)
         self.labelList.setDragDropMode(
            QtWidgets.QAbstractItemView.InternalMove)
         self.labelList.setParent(self)
@@ -247,6 +252,9 @@ class MainWindow(QtWidgets.QMainWindow):
         self.shape_dock.setObjectName('Labels')
         self.shape_dock.setWidget(self.labelList)
 
+
+
+
         self.uniqLabelList = UniqueLabelQListWidget()
         self.uniqLabelList.setToolTip(self.tr(
             "Select label to start annotating for it. "
@@ -1051,10 +1059,17 @@ class MainWindow(QtWidgets.QMainWindow):
             self.canvas.cross = False
             
     def immersiveMode(self):
-        if self.actions.hideOthers.isChecked() == True:
-            self.canvas.immersive = True
-        elif self.actions.hideOthers.isChecked() == False:
-            self.canvas.immersive = False
+        if self.canvas.immersive_ok:
+            if self.actions.hideOthers.isChecked() == True:
+                self.canvas.immersive = True
+            elif self.actions.hideOthers.isChecked() == False:
+                self.canvas.immersive = False
+        else:
+            if self.actions.hideOthers.isChecked() == True:
+                self.canvas.immersive = False
+            elif self.actions.hideOthers.isChecked() == False:
+                self.canvas.immersive = True
+    
     
     def toggleDrawingSensitive(self, drawing=True):
         """Toggle drawing sensitive.
@@ -1486,6 +1501,7 @@ class MainWindow(QtWidgets.QMainWindow):
             if self.actions.hideOthers.isChecked() == True:
                 self.canvas.keyboard_con()
                 self.canvas.immersive_first = True
+                self.canvas.immersive_ok = False
         else:
             self.canvas.undoLastLine()
             self.canvas.shapesBackups.pop()
